#    Copyright (c) 2014 Mirantis, Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from django.core import exceptions
from unittest import mock

from muranodashboard.dynamic_ui import fields
from openstack_dashboard.test import helpers


class FlavorFlave(object):
    def __init__(self, id, name, vcpus, disk, ram):
        self.name = name
        self.vcpus = vcpus
        self.disk = disk
        self.ram = ram
        self.id = id


class TestPasswordField(helpers.TestCase):
    def test_valid_input(self):
        f = fields.PasswordField('')
        for char in f.special_characters:
            if char != '\\':
                password = 'aA1111' + char
                self.assertIsNone(f.run_validators(password))

    def test_short_input(self):
        f = fields.PasswordField('')
        password = 'aA@111'
        self.assertRaises(exceptions.ValidationError, f.run_validators,
                          password)

    def test_input_without_special_characters(self):
        f = fields.PasswordField('')
        password = 'aA11111'
        self.assertRaises(exceptions.ValidationError, f.run_validators,
                          password)

    def test_input_without_digits(self):
        f = fields.PasswordField('')
        password = 'aA@@@@@'
        self.assertRaises(exceptions.ValidationError, f.run_validators,
                          password)

    def test_input_without_lowecase(self):
        f = fields.PasswordField('')
        password = 'A1@@@@@'
        self.assertRaises(exceptions.ValidationError, f.run_validators,
                          password)

    def test_input_without_uppercase(self):
        f = fields.PasswordField('')
        password = 'a1@@@@@'
        self.assertRaises(exceptions.ValidationError, f.run_validators,
                          password)
